/***************************************************************************
 *   Copyright Brian Ledbetter 2001-2003 <brian@shadowcom.net>             *
 *   Copyright Ravikiran Rajagopal 2003                                    *
 *   ravi@ee.eng.ohio-state.edu                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License (version 2) as   *
 *   published by the Free Software Foundation. (The original KSplash/ML   *
 *   codebase (upto version 0.95.3) is BSD-licensed.)                      *
 *                                                                         *
 ***************************************************************************/

#include <qlabel.h>
#include <qwidget.h>

#include <kapplication.h>
#include <kconfig.h>
#include <kdebug.h>
#include <kdialogbase.h>
#include <kgenericfactory.h>
#include <kglobalsettings.h>
#include <klocale.h>
#include <ksplash/objkstheme.h>
#include <kstandarddirs.h>

#include "theme2k.h"
#include "theme2k.moc"

K_EXPORT_COMPONENT_FACTORY( libksplash2k, KGenericFactory<Theme2k> );

Cfg2k::Cfg2k( KConfig * )
{}

Theme2k::Theme2k( QWidget *parent, const char *name, const QStringList &args  )
    :ThemeEngine( parent, name, args )
{
  readSettings();
  initUi();
}

void Theme2k::initUi()
{
  QVBox *vbox = new QVBox( this );
  vbox->setFrameShape( QFrame::WinPanel );
  vbox->setFrameShadow( QFrame::Raised );

  QHBox *labelBox = new QHBox( vbox );
  labelBox->setPalette( mTBgColor );
  labelBox->setMargin( 1 );
  QLabel *lbl = new QLabel( mWndTitle, labelBox );
  lbl->setFont( QFont( "Arial", 12, QFont::Bold ) );
  lbl->setPaletteForegroundColor( mTFgColor );

  QLabel *logo = new QLabel( vbox );
  logo->setPalette( Qt::white );

  QString px( locate( "appdata", mTheme->themeDir() + (mLogoFile.isNull()?QString("/Logo.png"):mLogoFile) ) );
  if (px.isNull())
    px = locate("appdata","pics/splash_top.png");
  if( !px.isNull() )
  {
    QPixmap pix( px );
    logo->setPixmap( pix );
  }
  else
  {
    logo->setText( "<B>KDE</B>2000" );
    logo->setAlignment( AlignCenter|AlignVCenter );
  }

  mRotator = new RotWidget( vbox, mRotColor1, mRotColor2, mRotSpeed );

  QHBox *hbox = new QHBox( vbox );
  labelBox->setSpacing( 4 );
  labelBox->setMargin( 4 );

  mText = new QLabel( hbox );
  mText->setPaletteForegroundColor( mTBgColor );
  mText->setPaletteBackgroundColor( mTFgColor );
  mText->setText( mWndTitle );
  mText->setFixedHeight( 48 );

  setFixedSize( vbox->sizeHint() );
  QRect rect(KGlobalSettings::splashScreenDesktopGeometry());
  move( rect.x() + (rect.width() - size().width())/2,
        rect.y() + (rect.height() - size().height())/2 );
}

void Theme2k::readSettings()
{
  if( !mTheme )
    return;

  KConfig *cfg = mTheme->themeConfig();
  if( !cfg )
    return;

  cfg->setGroup( QString("KSplash Theme: %1").arg(mTheme->theme()) );

  QColor DefaultTBgColor( Qt::darkBlue );
  QColor DefaultTFgColor( Qt::white );

  mTBgColor = cfg->readColorEntry( "Title Background Color", &DefaultTBgColor );
  mTFgColor = cfg->readColorEntry( "Title Foreground Color", &DefaultTFgColor );

  QColor DefaultRot1( Qt::darkBlue );
  QColor DefaultRot2( Qt::cyan );
  mRotColor1 = cfg->readColorEntry( "Rotator Color 1", &DefaultRot1 );
  mRotColor2 = cfg->readColorEntry( "Rotator Color 2", &DefaultRot2 );

  mRotSpeed = cfg->readNumEntry( "Rotator Speed", 30 );
  mWndTitle = cfg->readEntry( "Window Title", i18n("Please wait...") );
  mLogoFile = cfg->readEntry( "Logo File", QString::null );
}
